@@ -1,26 +1,21 @@
 package DateTime::TimeZone::Local;
-
+$DateTime::TimeZone::Local::VERSION = '1.64';
 use strict;
 use warnings;
 
-use vars qw( $VERSION );
-$VERSION = '0.01';
-
+use Class::Load qw( is_class_loaded load_class try_load_class );
 use DateTime::TimeZone;
 use File::Spec;
 
-
-sub TimeZone
-{
+sub TimeZone {
     my $class = shift;
 
     my $subclass = $class->_load_subclass();
 
-    for my $meth ( $subclass->Methods() )
-    {
-	my $tz = $subclass->$meth();
+    for my $meth ( $subclass->Methods() ) {
+        my $tz = $subclass->$meth();
 
-	return $tz if $tz;
+        return $tz if $tz;
     }
 
     die "Cannot determine local time zone\n";
@@ -30,69 +25,55 @@ sub TimeZone
     # Stolen from File::Spec. My theory is that other folks can write
     # the non-existent modules if they feel a need, and release them
     # to CPAN separately.
-    my %subclass = ( MSWin32 => 'Win32',
-                     VMS     => 'VMS',
-                     MacOS   => 'Mac',
-                     os2     => 'OS2',
-                     epoc    => 'Epoc',
-                     NetWare => 'Win32',
-                     symbian => 'Win32',
-                     dos     => 'OS2',
-                     cygwin  => 'Unix',
-                   );
+    my %subclass = (
+        MSWin32 => 'Win32',
+        VMS     => 'VMS',
+        MacOS   => 'Mac',
+        os2     => 'OS2',
+        epoc    => 'Epoc',
+        NetWare => 'Win32',
+        symbian => 'Win32',
+        dos     => 'OS2',
+        cygwin  => 'Unix',
+    );
 
-    sub _load_subclass
-    {
+    sub _load_subclass {
         my $class = shift;
 
-        my $os_name = $subclass{ $^O } || $^O;
+        my $os_name = $subclass{$^O} || $^O;
         my $subclass = $class . '::' . $os_name;
 
-        return $subclass if $subclass->can('Methods');
+        return $subclass if is_class_loaded($subclass);
 
-        local $@;
-        eval "use $subclass";
-        if ( my $e = $@ )
-        {
-            if ( $e =~ /locate.+$os_name/ )
-            {
-                $subclass = $class . '::' . 'Unix';
+        return $subclass if try_load_class($subclass);
 
-                eval "use $subclass";
-                die $@ if $@;
-            }
-            else
-            {
-                die $e;
-            }
-        }
+        $subclass = $class . '::Unix';
+
+        load_class($subclass);
 
         return $subclass;
     }
 }
 
-sub FromEnv
-{
+sub FromEnv {
     my $class = shift;
 
-    foreach my $var ( $class->EnvVars() )
-    {
-	if ( $class->_IsValidName( $ENV{$var} ) )
-	{
-	    my $tz;
+    foreach my $var ( $class->EnvVars() ) {
+        if ( $class->_IsValidName( $ENV{$var} ) ) {
+            my $tz;
             {
                 local $@;
+                local $SIG{__DIE__};
                 $tz = eval { DateTime::TimeZone->new( name => $ENV{$var} ) };
             }
             return $tz if $tz;
-	}
+        }
     }
 
     return;
 }
 
-sub _IsValidName
-{
+sub _IsValidName {
     shift;
 
     return 0 unless defined $_[0];
@@ -101,16 +82,22 @@ sub _IsValidName
     return $_[0] =~ m{^[\w/\-\+]+$};
 }
 
-
-
 1;
 
+# ABSTRACT: Determine the local system's time zone
+
 __END__
 
+=pod
+
 =head1 NAME
 
 DateTime::TimeZone::Local - Determine the local system's time zone
 
+=head1 VERSION
+
+version 1.64
+
 =head1 SYNOPSIS
 
   my $tz = DateTime::TimeZone->new( name => 'local' );
@@ -174,7 +161,7 @@ list of env vars to be checked by C<< $class->FromEnv() >>.
 =head2 $class->_IsValidName($name)
 
 Given a possible time zone name, this returns a boolean indicating
-whether or not the the name looks valid. It always return false for
+whether or not the name looks valid. It always return false for
 "local" in order to avoid infinite loops.
 
 =head1 EXAMPLE SUBCLASS
@@ -202,15 +189,13 @@ Here is a simple example subclass:
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003-2008 David Rolsky.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2014 by Dave Rolsky.
 
-The full text of the license can be found in the LICENSE file included
-with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
