@@ -1,14 +1,15 @@
 package DateTime::TimeZone::UTC;
-
+$DateTime::TimeZone::UTC::VERSION = '1.64';
 use strict;
+use warnings;
 
-use vars qw ($VERSION);
-$VERSION = 0.01;
-
-use DateTime::TimeZone;
-use base 'DateTime::TimeZone';
+use parent 'Class::Singleton', 'DateTime::TimeZone';
 
 sub new {
+    return shift->instance;
+}
+
+sub _new_instance {
     my $class = shift;
 
     return bless { name => 'UTC' }, $class;
@@ -27,12 +28,20 @@ sub is_utc {1}
 
 1;
 
+# ABSTRACT: The UTC time zone
+
 __END__
 
+=pod
+
 =head1 NAME
 
 DateTime::TimeZone::UTC - The UTC time zone
 
+=head1 VERSION
+
+version 1.64
+
 =head1 SYNOPSIS
 
   my $utc_tz = DateTime::TimeZone::UTC->new;
@@ -52,15 +61,13 @@ C<category()> method returns undef and C<is_utc()> returns true.
 
 =head1 AUTHOR
 
-Dave Rolsky, <autarch@urth.org>
+Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2003-2008 David Rolsky.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2014 by Dave Rolsky.
 
-The full text of the license can be found in the LICENSE file included
-with this module.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
